PostgresTrxClient class
Low-level transaction-scoped Postgres session executor.
This is an implementation detail of KnexPostgres. User code should
interact with KnexPostgresTransaction received from KnexPostgres.trx,
which routes queries through the KnexInterceptorPipeline.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
[String? tableName]) → QueryBuilder -
Callable shorthand for
queryBuilder().table(name)within the PG dialect. -
delete(
QueryBuilder query) → Future< List< Map< >String, dynamic> > - Executes a DELETE query inside this transaction.
-
execute(
QueryBuilder query) → Future< List< Map< >String, dynamic> > - Executes any compiled query inside this transaction.
-
insert(
QueryBuilder query) → Future< List< Map< >String, dynamic> > - Executes an INSERT query inside this transaction.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rawSql(
String sql, [List? bindings]) → Future< List< Map< >String, dynamic> > - Executes raw SQL inside this transaction.
-
select(
QueryBuilder query) → Future< List< Map< >String, dynamic> > - Executes a SELECT-style query inside this transaction.
-
toString(
) → String -
A string representation of this object.
inherited
-
trx<
T> (Future< T> callback(PostgresTrxClient trx)) → Future<T> -
Run
callbackinside a savepoint on this already-open transaction. -
update(
QueryBuilder query) → Future< List< Map< >String, dynamic> > - Executes an UPDATE query inside this transaction.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited